@@ -11,13 +11,16 @@ These can be generated using the `column` and `literal` function:
 - `literal()` expects either a float, or boolean value
 
 The result of these functions can then be combined using the built-in python arithmetic operations.
->>> literal(1) + column("a") / column("b")
-{'+': [{'lit': [1.0]}, {'/': [{'ref': ['a']}, {'ref': ['b']}]}]}
 
-A veriety of arithmetic functions are provided to allow creation of more complex mathematical expressions,
+>>> literal(1) + column("a") / column("b")
+
+``{'+': [{'lit': [1.0]}, {'/': [{'ref': ['a']}, {'ref': ['b']}]}]}``
+
+A variety of arithmetic functions are provided to allow creation of more complex mathematical expressions,
 such as `sin`, `cos` or `abs`. These mirror the behaviour of the respective function in the `math` standard library.
 
 """
+import math
 import numbers
 from typing import List, Union
 
@@ -42,7 +45,7 @@ def _validate_dict(d: dict):
             raise TypeError("Invalid key type")
         if not isinstance(d[k], list):
             raise ValueError("Invalid value type")
-        if k in ["lit", "ref"]:
+        if k in ["lit", "ref", "const"]:
             if len(d[k]) != 1:
                 raise ValueError("Invalid value format")
             if not isinstance(d[k][0], (bool, str, numbers.Real)):
@@ -59,7 +62,7 @@ class CalculatedColumnExpression(dict):
     Supports `+`, `-`, `*`, `/`, `**` arithmetic operators between instances of itself.
 
     Supports `>`, `>=`, `<`, `<=`, `==`, `!=` comparison operators between itself
-        (returning another Calculated Column Expression. To perform actual comparison, call `to_dict()` first)
+    (returning another Calculated Column Expression. To perform actual comparison, call `to_dict()` first)
 
     Supports boolean combination using bitwise operators:
 
@@ -69,11 +72,20 @@ class CalculatedColumnExpression(dict):
     """
 
     def __init__(self, *args, **kwargs):
+        """
+        Accepts the same arguments as dict().
+
+        The passed arguments must represent a valid calculated column expression.
+        We recommend you use the `literal()` and `column()` functions to construct valid
+        expressions rather than instantiating this directly.
+        """
         super().__init__(*args, **kwargs)
         try:
             _validate_dict(self)
         except (AttributeError, AssertionError) as e:
-            raise ValueError("Invalid argument to CalculatedColumnExpression") from e
+            raise ValueError(
+                "Invalid argument to CalculatedColumnExpression"
+            ) from e
 
     def __add__(self, other) -> "CalculatedColumnExpression":
         if isinstance(other, float):
@@ -259,8 +271,12 @@ class CalculatedColumnExpression(dict):
             or not isinstance(true_, CalculatedColumnExpression)
             or not isinstance(false_, CalculatedColumnExpression)
         ):
-            raise TypeError("All arguments to if_ must be CalculatedColumnExpressions")
-        return CalculatedColumnExpression({"if": cond, "then": true_, "else": false_})
+            raise TypeError(
+                "All arguments to if_ must be CalculatedColumnExpressions"
+            )
+        return CalculatedColumnExpression(
+            {"if": cond, "then": true_, "else": false_}
+        )
 
     @staticmethod
     def col(other) -> "CalculatedColumnExpression":
@@ -286,6 +302,19 @@ class CalculatedColumnExpression(dict):
         else:
             return CalculatedColumnExpression({"lit": [float(other)]})
 
+    @staticmethod
+    def const(other) -> "CalculatedColumnExpression":
+        if isinstance(other, dict):
+            if "const" not in other:
+                raise ValueError("Invalid argument to const")
+            return CalculatedColumnExpression(other)
+        elif isinstance(other, str):
+            if other not in {"nan", "pi", "e"}:
+                raise ValueError("Invalid argument to const")
+            return CalculatedColumnExpression({"const": [other]})
+        else:
+            raise ValueError("Invalid argument to const")
+
     def __setitem__(self, key, value):
         raise TypeError("Updating CalculatedColumnExpressions not supported")
 
@@ -329,7 +358,9 @@ class CalculatedColumnExpression(dict):
             op = self.get_operator()
             return {
                 op: [
-                    x.to_dict() if isinstance(x, CalculatedColumnExpression) else x
+                    x.to_dict()
+                    if isinstance(x, CalculatedColumnExpression)
+                    else x
                     for x in self.get_arguments()
                 ]
             }
@@ -342,7 +373,21 @@ def column(col: str) -> _CCE:
     return _CCE.col(col)
 
 
+e = _CCE.const("e")
+
+pi = _CCE.const("pi")
+
+nan = _CCE.const("nan")
+
+
 def literal(val: Union[int, float, bool]) -> _CCE:
+    if isinstance(val, float):
+        if val == math.pi:
+            return _CCE.const("pi")
+        elif val == math.e:
+            return _CCE.const("e")
+        elif math.isnan(val):
+            return _CCE.const("nan")
     return _CCE.lit(val)
 
 
@@ -412,7 +457,11 @@ def sum_(elements: List[_CCE]) -> _CCE:
     if len(elements) == 0:
         raise ValueError("Must have at least one argument")
     if not all(isinstance(x, CalculatedColumnExpression) for x in elements):
-        raise TypeError("All elements must be CalculatedColumnExpression instances")
+        raise TypeError(
+            "All elements must be CalculatedColumnExpression instances"
+        )
+    if len(elements) == 1:
+        return elements[0]
     return _CCE({"sum": elements})
 
 
@@ -420,7 +469,11 @@ def product(elements: List[_CCE]) -> _CCE:
     if len(elements) == 0:
         raise ValueError("Must have at least one argument")
     if not all(isinstance(x, CalculatedColumnExpression) for x in elements):
-        raise TypeError("All elements must be CalculatedColumnExpression instances")
+        raise TypeError(
+            "All elements must be CalculatedColumnExpression instances"
+        )
+    if len(elements) == 1:
+        return elements[0]
     return _CCE({"product": elements})
 
 
@@ -428,7 +481,11 @@ def min_(elements: List[_CCE]) -> _CCE:
     if len(elements) == 0:
         raise ValueError("Must have at least one argument")
     if not all(isinstance(x, CalculatedColumnExpression) for x in elements):
-        raise TypeError("All elements must be CalculatedColumnExpression instances")
+        raise TypeError(
+            "All elements must be CalculatedColumnExpression instances"
+        )
+    if len(elements) == 1:
+        return elements[0]
     return _CCE({"min": elements})
 
 
@@ -436,7 +493,11 @@ def max_(elements: List[_CCE]) -> _CCE:
     if len(elements) == 0:
         raise ValueError("Must have at least one argument")
     if not all(isinstance(x, CalculatedColumnExpression) for x in elements):
-        raise TypeError("All elements must be CalculatedColumnExpression instances")
+        raise TypeError(
+            "All elements must be CalculatedColumnExpression instances"
+        )
+    if len(elements) == 1:
+        return elements[0]
     return _CCE({"max": elements})
 
 
@@ -444,7 +505,11 @@ def mean(elements: List[_CCE]) -> _CCE:
     if len(elements) == 0:
         raise ValueError("Must have at least one argument")
     if not all(isinstance(x, CalculatedColumnExpression) for x in elements):
-        raise TypeError("All elements must be CalculatedColumnExpression instances")
+        raise TypeError(
+            "All elements must be CalculatedColumnExpression instances"
+        )
+    if len(elements) == 1:
+        return elements[0]
     return _CCE({"avg": elements})
 
 
@@ -452,7 +517,11 @@ def avg(elements: List[_CCE]) -> _CCE:
     if len(elements) == 0:
         raise ValueError("Must have at least one argument")
     if not all(isinstance(x, CalculatedColumnExpression) for x in elements):
-        raise TypeError("All elements must be CalculatedColumnExpression instances")
+        raise TypeError(
+            "All elements must be CalculatedColumnExpression instances"
+        )
+    if len(elements) == 1:
+        return elements[0]
     return _CCE({"avg": elements})
 
 
