@@ -399,6 +399,45 @@ class Configuration(client.Configuration):
         return auth
 
 
+def await_uploaded(get_dataset):
+    """
+    Block until the dataset is "uploaded"
+
+    Parameters
+    ----------
+    get_dataset : func
+        Function which returns the dataset metadata when called
+
+    Returns
+    -------
+    Dataset
+        The dataset metadata after it has been processed
+    """
+    status = None
+    err_count = 0
+    while True:
+        try:
+            dataset = get_dataset()
+        except ServiceException:
+            err_count += 1
+            if err_count > 60:
+                raise
+            time.sleep(1)
+            continue
+        err_count = 0
+        status = dataset["status"]
+        if status in ["uploaded", "failed"]:
+            break
+        time.sleep(1)
+
+    if status != "uploaded":
+        raise RuntimeError(
+            f"Dataset {dataset['id']} did not complete successfully: {dataset['detail']}"
+        )
+
+    return dataset
+
+
 def await_trained(get_model):
     """
     Block until the model is 'trained' and a print progress bar with updates
