@@ -28,6 +28,7 @@ from alchemite_apiclient.model.column_group_request import ColumnGroupRequest
 from alchemite_apiclient.model.column_group_response import ColumnGroupResponse
 from alchemite_apiclient.model.column_group_response_all_of import ColumnGroupResponseAllOf
 from alchemite_apiclient.model.column_info import ColumnInfo
+from alchemite_apiclient.model.column_info_base import ColumnInfoBase
 from alchemite_apiclient.model.column_value import ColumnValue
 from alchemite_apiclient.model.column_value_nullable import ColumnValueNullable
 from alchemite_apiclient.model.consistent_optimization_job import ConsistentOptimizationJob
@@ -58,6 +59,7 @@ from alchemite_apiclient.model.dataset import Dataset
 from alchemite_apiclient.model.dataset1 import Dataset1
 from alchemite_apiclient.model.dataset_calculated_columns import DatasetCalculatedColumns
 from alchemite_apiclient.model.dataset_chunk import DatasetChunk
+from alchemite_apiclient.model.dataset_extensions import DatasetExtensions
 from alchemite_apiclient.model.dataset_favourite_query import DatasetFavouriteQuery
 from alchemite_apiclient.model.dataset_or_data import DatasetOrData
 from alchemite_apiclient.model.dataset_patch import DatasetPatch
@@ -145,6 +147,7 @@ from alchemite_apiclient.model.inline_response200 import InlineResponse200
 from alchemite_apiclient.model.inline_response2001 import InlineResponse2001
 from alchemite_apiclient.model.inline_response2002 import InlineResponse2002
 from alchemite_apiclient.model.inline_response2003 import InlineResponse2003
+from alchemite_apiclient.model.inline_response2003_normalization_values import InlineResponse2003NormalizationValues
 from alchemite_apiclient.model.inline_response2003_values import InlineResponse2003Values
 from alchemite_apiclient.model.inline_response2004 import InlineResponse2004
 from alchemite_apiclient.model.inline_response2005 import InlineResponse2005
@@ -211,6 +214,9 @@ from alchemite_apiclient.model.ot_sample_def_categorical import OTSampleDefCateg
 from alchemite_apiclient.model.ot_sample_def_continuous import OTSampleDefContinuous
 from alchemite_apiclient.model.ot_sample_definition import OTSampleDefinition
 from alchemite_apiclient.model.ot_set_inputs import OTSetInputs
+from alchemite_apiclient.model.opaque_column_info import OpaqueColumnInfo
+from alchemite_apiclient.model.opaque_column_info_all_of import OpaqueColumnInfoAllOf
+from alchemite_apiclient.model.opaque_model_column_info import OpaqueModelColumnInfo
 from alchemite_apiclient.model.optimization_job import OptimizationJob
 from alchemite_apiclient.model.optimize_parameters import OptimizeParameters
 from alchemite_apiclient.model.optimize_request import OptimizeRequest
