@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import csv
 from io import StringIO
 
@@ -30,7 +28,9 @@ model_name = "steels"
 api_response = api_default.version_get()
 print("------ API & Python Client Versions ------")
 print(api_response)
-print(f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})")
+print(
+    f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})"
+)
 print("------------------------------------------")
 
 ############################################################################
@@ -108,9 +108,7 @@ impute_request = {
     "return_column_headers": True,
     "data": impute_data,
 }
-response = api_models.models_id_impute_put(
-    model_id, impute_request=impute_request
-)
+response = api_models.models_id_impute_put(model_id, impute_request=impute_request)
 print("--- impute result ---")
 print(response)
 
