@@ -10,7 +10,7 @@ def test_training_outliers(
 
     # Get the training dataset outliers
     training_outliers_response = (
-        api_models.models_id_training_dataset_outliers_get(
+        api_models.models_id_training_dataset_outliers_put(
             model_id, _preload_content=False
         )
     )
